@@ -1,17 +1,16 @@
-from pytest import mark
+from io import BytesIO
 
 from translate.convert import po2html, test_convert
-from translate.misc import wStringIO
 
 
-class TestPO2Html(object):
+class TestPO2Html:
 
     def converthtml(self, posource, htmltemplate, includefuzzy=False):
         """helper to exercise the command line function"""
-        inputfile = wStringIO.StringIO(posource)
+        inputfile = BytesIO(posource.encode())
         print(inputfile.getvalue())
-        outputfile = wStringIO.StringIO()
-        templatefile = wStringIO.StringIO(htmltemplate)
+        outputfile = BytesIO()
+        templatefile = BytesIO(htmltemplate.encode())
         assert po2html.converthtml(inputfile, outputfile, templatefile, includefuzzy)
         print(outputfile.getvalue())
         return outputfile.getvalue().decode('utf-8')
@@ -57,27 +56,57 @@ sin.
 </body>'''
         assert htmlexpected.replace("\n", " ") in self.converthtml(posource, htmlsource).replace("\n", " ")
 
-    @mark.xfail(reason="Not Implemented")
+    def test_replace_substrings(self):
+        """Should replace substrings correctly, issue #3416"""
+        htmlsource = '''<!DOCTYPE html><html><head><title>sub-strings substitution</title></head><body>
+<h2>This is heading 2</h2>
+<p>The heading says: <b>This is heading 2</b></p>
+</body></html>'''
+        posource = '#:html.body.h2:2-1\nmsgid "This is heading 2"\nmsgstr "Αυτή είναι μία Ετικέτα 2"\n\n#html.body.p:3-1\nmsgid "The heading says: <b>This is heading 2</b>"\nmsgstr "Η ετικέτα λέει: <b>Αυτή είναι μία Ετικέτα 2</b>"\n'
+        htmlexpected = '''<!DOCTYPE html><html><head><title>sub-strings substitution</title></head><body>
+<h2>Αυτή είναι μία Ετικέτα 2</h2>
+<p>Η ετικέτα λέει: <b>Αυτή είναι μία Ετικέτα 2</b></p>
+</body></html>'''
+        assert htmlexpected in self.converthtml(posource, htmlsource)
+
+    def test_attribute_outside_translatable_content(self):
+        htmlsource = '<img alt="a picture"><p>A sentence.</p>'
+        posource = '''#: html:3\nmsgid "A sentence."\nmsgstr "'n Sin."\n#: html:1\nmsgid "a picture"\nmsgstr "n prentjie"\n'''
+        htmlexpected = '''<img alt="n prentjie"><p>'n Sin.</p>'''
+        assert htmlexpected in self.converthtml(posource, htmlsource)
+
+    def test_attribute_within_translatable_content_not_embedded(self):
+        htmlsource = '<p><img alt="a picture">A sentence.</p>'
+        posource = '''#: html:3\nmsgid "A sentence."\nmsgstr "'n Sin."\n#: html:1\nmsgid "a picture"\nmsgstr "n prentjie"\n'''
+        htmlexpected = '''<p><img alt="n prentjie">'n Sin.</p>'''
+        assert htmlexpected in self.converthtml(posource, htmlsource)
+
+    def test_attribute_embedded_within_translatable_content(self):
+        htmlsource = '<p>A sentence<img alt="a picture">.</p>'
+        posource = '''#: html:3\nmsgid "A sentence<img alt="a picture">."\nmsgstr "'n Sin<img alt="n prentjie">."\n'''
+        htmlexpected = '''<p>'n Sin<img alt="n prentjie">.</p>'''
+        assert htmlexpected in self.converthtml(posource, htmlsource)
+
+    def test_attribute_without_value(self):
+        htmlsource = '<ul><li><a href="logoColor.eps" download>EPS färg</a></li></ul>'
+        posource = '''#: html:3\nmsgid "EPS färg"\nmsgstr "EPS color"\n'''
+        htmlexpected = '''<li><a href="logoColor.eps" download>EPS color</a></li>'''
+        assert htmlexpected in self.converthtml(posource, htmlsource)
+
     def test_entities(self):
         """Tests that entities are handled correctly"""
         htmlsource = '<p>5 less than 6</p>'
-        posource = '#:html:3\nmsgid "5 less than 6"\nmsgstr "5 < 6"\n'
+        posource = '#:html:3\nmsgid "5 less than 6"\nmsgstr "5 &lt; 6"\n'
         htmlexpected = '<p>5 &lt; 6</p>'
         assert htmlexpected in self.converthtml(posource, htmlsource)
 
         htmlsource = '<p>Fish &amp; chips</p>'
-        posource = '#: html:3\nmsgid "Fish & chips"\nmsgstr "Vis & skyfies"\n'
+        posource = '#: html:3\nmsgid "Fish &amp; chips"\nmsgstr "Vis &amp; skyfies"\n'
         htmlexpected = '<p>Vis &amp; skyfies</p>'
         assert htmlexpected in self.converthtml(posource, htmlsource)
 
-    @mark.xfail(reason="Not Implemented")
     def test_escapes(self):
         """Tests that PO escapes are correctly handled"""
-        htmlsource = '<div>Row 1<br />Row 2</div>'
-        posource = '#: html:3\nmsgid "Row 1\\n"\n"Row 2"\nmsgstr "Ry 1\\n"\n"Ry 2"\n'
-        htmlexpected = '<div>Ry 1<br />Ry 2</div>'
-        assert htmlexpected in self.converthtml(posource, htmlsource)
-
         htmlsource = '<p>"leverage"</p>'
         posource = '#: html3\nmsgid "\\"leverage\\""\nmsgstr "\\"ek is dom\\""\n'
         htmlexpected = '<p>"ek is dom"</p>'
@@ -123,6 +152,7 @@ sin.
 
 class TestPO2HtmlCommand(test_convert.TestConvertCommand, TestPO2Html):
     """Tests running actual po2oo commands on files"""
+
     convertmodule = po2html
 
     def test_help(self, capsys):
