@@ -1,17 +1,17 @@
-# -*- coding: utf-8 -*-
+
+from io import BytesIO
 
 from pytest import mark, raises
 
 from translate.convert import po2php, test_convert
-from translate.misc import wStringIO
 from translate.storage import po
 
 
-class TestPO2Php(object):
+class TestPO2Php:
 
     def po2php(self, posource):
         """helper that converts po source to .php source without requiring files"""
-        inputfile = wStringIO.StringIO(posource)
+        inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
         convertor = po2php.po2php()
         outputphp = convertor.convertstore(inputpo)
@@ -19,9 +19,9 @@ class TestPO2Php(object):
 
     def merge2php(self, phpsource, posource):
         """helper that merges po translations to .php source without requiring files"""
-        inputfile = wStringIO.StringIO(posource)
+        inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
-        templatefile = wStringIO.StringIO(phpsource)
+        templatefile = BytesIO(phpsource.encode())
         #templatephp = php.phpfile(templatefile)
         convertor = po2php.rephp(templatefile, inputpo)
         outputphp = [line.decode('utf-8') for line in convertor.convertstore()]
@@ -38,9 +38,9 @@ msgstr "waarde"
 '''
         phpexpected = b'''$lang['name'] = 'waarde';
 '''
-        inputfile = wStringIO.StringIO(posource)
-        templatefile = wStringIO.StringIO(phptemplate)
-        outputfile = wStringIO.StringIO()
+        inputfile = BytesIO(posource.encode())
+        templatefile = BytesIO(phptemplate.encode())
+        outputfile = BytesIO()
         assert po2php.convertphp(inputfile, outputfile, templatefile) == 1
         assert outputfile.getvalue() == phpexpected
 
@@ -50,8 +50,8 @@ msgstr "waarde"
 msgid "value"
 msgstr "waarde"
 '''
-        inputfile = wStringIO.StringIO(posource)
-        outputfile = wStringIO.StringIO()
+        inputfile = BytesIO(posource.encode())
+        outputfile = BytesIO()
         with raises(ValueError):
             po2php.convertphp(inputfile, outputfile, None)
 
@@ -61,9 +61,9 @@ msgstr "waarde"
 msgid "value"
 msgstr ""
 '''
-        inputfile = wStringIO.StringIO(posource)
-        templatefile = wStringIO.StringIO('')
-        outputfile = wStringIO.StringIO()
+        inputfile = BytesIO(posource.encode())
+        templatefile = BytesIO(b'')
+        outputfile = BytesIO()
         assert po2php.convertphp(inputfile, outputfile, templatefile, False, 100) is False
         assert outputfile.getvalue() == b''
 
@@ -189,9 +189,11 @@ msgstr "Jaar"
         assert phpfile == [phpexpected]
 
     def test_multiline(self):
-        """Check that we convert multiline strings correctly.
+        """
+        Check that we convert multiline strings correctly.
 
-        Bug 1296."""
+        Bug 1296.
+        """
         posource = r'''#: $string['upgradesure']
 msgid ""
 "Your Moodle files have been changed, and you are\n"
@@ -301,6 +303,7 @@ msgstr "target2"
 
 class TestPO2PhpCommand(test_convert.TestConvertCommand, TestPO2Php):
     """Tests running actual po2php commands on files"""
+
     convertmodule = po2php
     defaultoptions = {"progress": "none"}
 
