@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
 # Copyright 2015 Sarah Hale
@@ -18,56 +17,57 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-""" Tests converting Gettext PO localisation files to .Net Resource (.resx) files """
+"""Tests converting Gettext PO localisation files to .Net Resource (.resx) files"""
+
+from io import BytesIO
 
 from translate.convert import po2resx, test_convert
 from translate.storage import po
-from translate.misc import wStringIO
 
 
-class TestPO2RESX(object):
-    XMLskeleton = '''<?xml version='1.0' encoding='UTF-8'?>
+class TestPO2RESX:
+    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
 <root>
   <xsd:schema xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata" id="root">
-    <xsd:import namespace="http://www.w3.org/XML/1998/namespace"/>
+    <xsd:import namespace="http://www.w3.org/XML/1998/namespace" />
     <xsd:element name="root" msdata:IsDataSet="true">
       <xsd:complexType>
         <xsd:choice maxOccurs="unbounded">
           <xsd:element name="metadata">
             <xsd:complexType>
               <xsd:sequence>
-                <xsd:element name="value" type="xsd:string" minOccurs="0"/>
+                <xsd:element name="value" type="xsd:string" minOccurs="0" />
               </xsd:sequence>
-              <xsd:attribute name="name" use="required" type="xsd:string"/>
-              <xsd:attribute name="type" type="xsd:string"/>
-              <xsd:attribute name="mimetype" type="xsd:string"/>
-              <xsd:attribute ref="xml:space"/>
+              <xsd:attribute name="name" use="required" type="xsd:string" />
+              <xsd:attribute name="type" type="xsd:string" />
+              <xsd:attribute name="mimetype" type="xsd:string" />
+              <xsd:attribute ref="xml:space" />
             </xsd:complexType>
           </xsd:element>
           <xsd:element name="assembly">
             <xsd:complexType>
-              <xsd:attribute name="alias" type="xsd:string"/>
-              <xsd:attribute name="name" type="xsd:string"/>
+              <xsd:attribute name="alias" type="xsd:string" />
+              <xsd:attribute name="name" type="xsd:string" />
             </xsd:complexType>
           </xsd:element>
           <xsd:element name="data">
             <xsd:complexType>
               <xsd:sequence>
-                <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1"/>
-                <xsd:element name="comment" type="xsd:string" minOccurs="0" msdata:Ordinal="2"/>
+                <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />
+                <xsd:element name="comment" type="xsd:string" minOccurs="0" msdata:Ordinal="2" />
               </xsd:sequence>
-              <xsd:attribute name="name" type="xsd:string" use="required" msdata:Ordinal="1"/>
-              <xsd:attribute name="type" type="xsd:string" msdata:Ordinal="3"/>
-              <xsd:attribute name="mimetype" type="xsd:string" msdata:Ordinal="4"/>
-              <xsd:attribute ref="xml:space"/>
+              <xsd:attribute name="name" type="xsd:string" use="required" msdata:Ordinal="1" />
+              <xsd:attribute name="type" type="xsd:string" msdata:Ordinal="3" />
+              <xsd:attribute name="mimetype" type="xsd:string" msdata:Ordinal="4" />
+              <xsd:attribute ref="xml:space" />
             </xsd:complexType>
           </xsd:element>
           <xsd:element name="resheader">
             <xsd:complexType>
               <xsd:sequence>
-                <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1"/>
+                <xsd:element name="value" type="xsd:string" minOccurs="0" msdata:Ordinal="1" />
               </xsd:sequence>
-              <xsd:attribute name="name" type="xsd:string" use="required"/>
+              <xsd:attribute name="name" type="xsd:string" use="required" />
             </xsd:complexType>
           </xsd:element>
         </xsd:choice>
@@ -81,19 +81,18 @@ class TestPO2RESX(object):
     <value>2.0</value>
   </resheader>
   %s
-</root>
-'''
+</root>'''
 
     def po2resx(self, resxsource, po_source):
-        """ Helper that merges po translations to .resx source without requiring files """
+        """Helper that merges po translations to .resx source without requiring files"""
         po_store = po.pofile(po_source.encode('utf-8'))
-        template_file = wStringIO.StringIO(resxsource)
+        template_file = BytesIO(resxsource.encode())
         convertor = po2resx.po2resx(template_file, po_store)
         output_resx = convertor.convertstore()
         return output_resx.decode('utf-8')
 
     def test_simpleunit(self):
-        """ Checks that a simple po entry definition converts properly to a resx entry """
+        """Checks that a simple po entry definition converts properly to a resx entry"""
         po_source = r'''#: key
 msgid "Source Text"
 msgstr "Some translated text"'''
@@ -135,7 +134,7 @@ msgstr "Toepassings"
         assert resx_file == expected_output
 
     def test_multiline(self):
-        """ Test multiline po entry """
+        """Test multiline po entry"""
         po_source = r'''#: ResourceKey
 msgid "First part "
 "and extra"
@@ -151,7 +150,7 @@ msgstr "Eerste deel "
         assert resx_file == expected_output
 
     def test_escapednewlines(self):
-        """ Test the escaping of newlines """
+        """Test the escaping of newlines"""
         po_source = r'''#: ResourceKey
 msgid "First line\nSecond line"
 msgstr "Eerste lyn\nTweede lyn"
@@ -167,7 +166,7 @@ Tweede lyn</value>
         assert resx_file == expected_output
 
     def test_escapedtabs(self):
-        """ Test the escaping of tabs """
+        """Test the escaping of tabs"""
         po_source = r'''#: ResourceKey
 msgid "First column\tSecond column"
 msgstr "Eerste kolom\tTweede kolom"
@@ -182,7 +181,7 @@ msgstr "Eerste kolom\tTweede kolom"
         assert resx_file == expected_output
 
     def test_escapedquotes(self):
-        """ Test the escaping of quotes (and slash) """
+        """Test the escaping of quotes (and slash)"""
         po_source = r'''#: ResourceKey
 msgid "Hello \"Everyone\""
 msgstr "Good day \"All\""
@@ -200,7 +199,7 @@ msgstr "Gebruik \\\"."
         assert resx_file == expected_output
 
     def test_exclusions(self):
-        """ Test that empty and fuzzy messages are excluded """
+        """Test that empty and fuzzy messages are excluded"""
         po_source = r'''#: ResourceKey
 #, fuzzy
 msgid "One"
@@ -215,29 +214,29 @@ msgid ""
 msgstr "Drie"
 '''
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-    <value/>
+    <value />
   </data>
   <data name="ResourceKey2" xml:space="preserve">
-    <value/>
+    <value />
   </data>
   <data name="ResourceKey3" xml:space="preserve">
-    <value/>
+    <value />
   </data>'''
         expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
-    <value/>
+    <value />
   </data>
   <data name="ResourceKey2" xml:space="preserve">
-    <value/>
+    <value />
   </data>
   <data name="ResourceKey3" xml:space="preserve">
-    <value/>
+    <value />
   </data>'''
         resx_file = self.po2resx(resx_template, po_source)
         assert resx_file == expected_output
 
     def test_automaticcomments(self):
-        """ Tests that automatic comments are imported """
-        po_source = u'''#. This is a comment
+        """Tests that automatic comments are imported"""
+        po_source = '''#. This is a comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -245,7 +244,7 @@ msgstr "Bézier-kurwe"
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value></value>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is a comment</comment>
   </data>'''
@@ -253,8 +252,8 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_automaticcomments_existingcomment(self):
-        """ Tests a differing automatic comment is added if there is an existing automatic comment """
-        po_source = u'''#. This is a new comment
+        """Tests a differing automatic comment is added if there is an existing automatic comment"""
+        po_source = '''#. This is a new comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -263,7 +262,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>This is an existing comment</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 This is a new comment</comment>
@@ -272,8 +271,8 @@ This is a new comment</comment>
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of automatic comments if it already exists and hasn't changed """
-        po_source = u'''#. This is an existing comment
+        """Tests there is no duplication of automatic comments if it already exists and hasn't changed"""
+        po_source = '''#. This is an existing comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -282,7 +281,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>This is an existing comment</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment</comment>
   </data>'''
@@ -290,9 +289,11 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_automaticcomments_existingduplicatecommentwithwhitespace(self):
-        """ Tests there is no duplication of automatic comments if it already exists, hasn't changed but has leading or
-        trailing whitespaces """
-        po_source = u'''#.  This is an existing comment with leading and trailing spaces
+        """
+        Tests there is no duplication of automatic comments if it already
+        exists, hasn't changed but has leading or trailing whitespaces
+        """
+        po_source = '''#.  This is an existing comment with leading and trailing spaces
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -301,7 +302,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment> This is an existing comment with leading and trailing spaces </comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment with leading and trailing spaces</comment>
   </data>'''
@@ -309,8 +310,8 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_translatorcomments(self):
-        """ Tests that translator comments are imported """
-        po_source = u'''# This is a translator comment : 22.12.14
+        """Tests that translator comments are imported"""
+        po_source = '''# This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -318,7 +319,7 @@ msgstr "Bézier-kurwe"
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value></value>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is a translator comment : 22.12.14]</comment>
   </data>'''
@@ -326,8 +327,8 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_translatorcomments_existingcomment(self):
-        """ Tests a differing translator comment is added if there is an existing translator comment """
-        po_source = u'''# This is a new translator comment
+        """Tests a differing translator comment is added if there is an existing translator comment"""
+        po_source = '''# This is a new translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -336,7 +337,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>[Translator Comment: This is an existing comment]</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is an existing comment]
 [Translator Comment: This is a new translator comment]</comment>
@@ -345,8 +346,8 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_translatorcomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of translator comments if it already exists and hasn't changed """
-        po_source = u'''# This is an existing translator comment
+        """Tests there is no duplication of translator comments if it already exists and hasn't changed"""
+        po_source = '''# This is an existing translator comment
 #: ResourceKey
 msgid "Bézier curve"
 msgstr "Bézier-kurwe"
@@ -355,7 +356,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>[Translator Comment: This is an existing translator comment]</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>[Translator Comment: This is an existing translator comment]</comment>
   </data>'''
@@ -363,8 +364,8 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_combocomments(self):
-        """ Tests that translator comments and automatic comments are imported """
-        po_source = u'''#. This is a developer comment
+        """Tests that translator comments and automatic comments are imported"""
+        po_source = '''#. This is a developer comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
@@ -373,7 +374,7 @@ msgstr "Bézier-kurwe"
         resx_template = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value></value>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is a developer comment
 [Translator Comment: This is a translator comment : 22.12.14]</comment>
@@ -382,9 +383,11 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_combocomments_existingduplicatecomment(self):
-        """ Tests there is no duplication of automatic comment if it already exists and hasn't changed, but still adds
-        the translator comment """
-        po_source = u'''#. This is an existing comment
+        """
+        Tests there is no duplication of automatic comment if it already exists
+        and hasn't changed, but still adds the translator comment
+        """
+        po_source = '''#. This is an existing comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
@@ -394,7 +397,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>This is an existing comment</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 [Translator Comment: This is a translator comment : 22.12.14]</comment>
@@ -403,9 +406,11 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
     def test_combocomments_existingcomment(self):
-        """ Tests a differing automatic comment is added if there is an existing automatic comment, but still adds
-        the translator comment """
-        po_source = u'''#. This is a new comment
+        """
+        Tests a differing automatic comment is added if there is an existing
+        automatic comment, but still adds the translator comment
+        """
+        po_source = '''#. This is a new comment
 # This is a translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
@@ -415,7 +420,7 @@ msgstr "Bézier-kurwe"
     <value></value>
     <comment>This is an existing comment</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 This is a new comment
@@ -425,8 +430,8 @@ This is a new comment
         assert resx_file == expected_output
 
     def test_existingcomments(self):
-        """ Tests that no extra space is added when there are no changes to existing comments"""
-        po_source = u'''#. This is an existing comment
+        """Tests that no extra space is added when there are no changes to existing comments"""
+        po_source = '''#. This is an existing comment
 # This is an existing translator comment : 22.12.14
 #: ResourceKey
 msgid "Bézier curve"
@@ -437,7 +442,7 @@ msgstr "Bézier-kurwe"
     <comment>This is an existing comment
 [Translator Comment: This is an existing translator comment : 22.12.14]</comment>
   </data>'''
-        expected_output = self.XMLskeleton % u'''<data name="ResourceKey" xml:space="preserve">
+        expected_output = self.XMLskeleton % '''<data name="ResourceKey" xml:space="preserve">
     <value>Bézier-kurwe</value>
     <comment>This is an existing comment
 [Translator Comment: This is an existing translator comment : 22.12.14]</comment>
@@ -446,11 +451,12 @@ msgstr "Bézier-kurwe"
         assert resx_file == expected_output
 
 
-class TestPO2TSCommand(test_convert.TestConvertCommand, TestPO2RESX):
-    """ Tests running actual po2ts commands on files """
+class TestPO2RESXCommand(test_convert.TestConvertCommand, TestPO2RESX):
+    """Tests running actual po2resx commands on files"""
+
     convertmodule = po2resx
 
     def test_help(self, capsys):
-        """ Tests getting help """
+        """Tests getting help"""
         options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
