@@ -3,8 +3,10 @@ from translate.lang.team import guess_language
 
 
 def test_simple():
-    """test the regex, team snippet and language name snippets at a high
-    level"""
+    """
+    test the regex, team snippet and language name snippets at a high
+    level
+    """
     # standard regex guess
     assert guess_language("ab@li.org") == "ab"
     # We never suggest 'en', it's always a mistake
