@@ -1,5 +1,3 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
 
 from translate.lang import factory
 
@@ -7,7 +5,7 @@ from translate.lang import factory
 def test_sentences():
     """Tests basic functionality of sentence segmentation."""
     language = factory.getlanguage('uk')
-    sentences = language.sentences(u"")
+    sentences = language.sentences("")
     assert sentences == []
-    sentences = language.sentences(u"Ел. пошта")
-    assert sentences == [u"Ел. пошта"]
+    sentences = language.sentences("Ел. пошта")
+    assert sentences == ["Ел. пошта"]
