@@ -294,6 +294,13 @@ class AndroidResourceUnit(base.TranslationUnit):
                                for child in cloned_target.iterchildren()])
             return target
 
+    def set_xml_text_plain(self, target, xmltarget):
+        # Remove possible old elements
+        for x in xmltarget.iterchildren():
+            xmltarget.remove(x)
+        # Handle text only
+        xmltarget.text = self.escape(target)
+
     def set_xml_text_value(self, target, xmltarget):
         if '<' in target or '&' in target:
             # Try to handle it as legacy XML
@@ -301,19 +308,21 @@ class AndroidResourceUnit(base.TranslationUnit):
             if self._store is not None:
                 cloned_doc = copy.deepcopy(self._store.document)
                 cloned_root = cloned_doc.getroot()
-                for child in cloned_root.iterchildren():
-                    cloned_root.remove(child)
-                template = etree.tostring(cloned_doc, encoding='unicode')
+                cloned_root.clear()
+                template = etree.tostring(cloned_doc, encoding='unicode', doctype=copy.copy(self._store._doctype))
             else:
                 template = '<resources></resources>'
+            if '</resources>' in template:
+                match = "</resources>"
+                prefix = ""
+            else:
+                match = "<resources/>"
+                prefix = "<resources>"
+            newstring = template.replace(match, f'{prefix}<string>{target}</string></resources>')
             try:
-                newstring = etree.fromstring(
-                    template.replace('</resources>', '<string>%s</string></resources>' % target),
-                    parser
-                )[0]
+                newstring = etree.fromstring(newstring, parser)[0]
             except Exception:
-                # Fallback to string with XML escaping
-                xmltarget.text = self.escape(target)
+                self.set_xml_text_plain(target, xmltarget)
             else:
                 # Escape all text parts.
                 if newstring.text is not None:
@@ -334,11 +343,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                 for x in newstring.iterchildren():
                     xmltarget.append(x)
         else:
-            # Remove possible old elements
-            for x in xmltarget.iterchildren():
-                xmltarget.remove(x)
-            # Handle text only
-            xmltarget.text = self.escape(target)
+            self.set_xml_text_plain(target, xmltarget)
 
     @property
     def target(self):
