@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -48,16 +47,10 @@ Escaping
 
     Functions allow for :func:`._escape` and :func:`._unescape`.
 """
-from __future__ import unicode_literals
 
-import six
-if six.PY2:
-    from backports import csv
-else:
-    import csv
+import csv
 
 from translate.lang import data
-from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
@@ -105,7 +98,7 @@ class CatkeysDialect(csv.Dialect):
 csv.register_dialect("catkeys", CatkeysDialect)
 
 
-class CatkeysHeader(object):
+class CatkeysHeader:
     """A catkeys translation memory header"""
 
     def __init__(self, header=None):
@@ -113,7 +106,11 @@ class CatkeysHeader(object):
         if not header:
             self._header_dict = self._create_default_header()
         elif isinstance(header, dict):
-            self._header_dict = header
+            for key in FIELDNAMES_HEADER:
+                value = header.get(key, "")
+                if value is None:
+                    value = ""
+                self._header_dict[key] = value
 
     def _create_default_header(self):
         """Create a default catkeys header"""
@@ -128,8 +125,13 @@ class CatkeysHeader(object):
         self._header_dict['language'] = data.languages[newlang][0].lower()
     targetlanguage = property(None, settargetlanguage)
 
+    def setchecksum(self, checksum):
+        """Set the checksum for the file"""
+        if not checksum:
+            return
+        self._header_dict['checksum'] = str(checksum)
+
 
-@six.python_2_unicode_compatible
 class CatkeysUnit(base.TranslationUnit):
     """A catkeys translation memory unit"""
 
@@ -137,7 +139,7 @@ class CatkeysUnit(base.TranslationUnit):
         self._dict = {}
         if source:
             self.source = source
-        super(CatkeysUnit, self).__init__(source)
+        super().__init__(source)
 
     def getdict(self):
         """Get the dictionary of values for a catkeys line"""
@@ -149,8 +151,13 @@ class CatkeysUnit(base.TranslationUnit):
         :param newdict: a new dictionary with catkeys line elements
         :type newdict: Dict
         """
-        # TODO First check that the values are OK
-        self._dict = newdict
+        # Process the input values
+        self._dict = {}
+        for key in FIELDNAMES:
+            value = newdict.get(key, "")
+            if value is None:
+                value = ""
+            self._dict[key] = value
     dict = property(getdict, setdict)
 
     def _get_source_or_target(self, key):
@@ -177,11 +184,6 @@ class CatkeysUnit(base.TranslationUnit):
         self._rich_source = None
         self._set_source_or_target('source', source)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     @property
     def target(self):
         return self._get_source_or_target('target')
@@ -191,32 +193,30 @@ class CatkeysUnit(base.TranslationUnit):
         self._rich_target = None
         self._set_source_or_target('target', target)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def getnotes(self, origin=None):
         if not origin or origin in ["programmer", "developer", "source code"]:
-            return self._dict["comment"]
-        return u""
+            return self._dict.get("comment", "")
+        return ""
 
     def getcontext(self):
-        return self._dict["context"]
+        return self._dict.get("context", "")
+
+    def setcontext(self, context):
+        self._dict["context"] = context
 
     def getid(self):
         context = self.getcontext()
         notes = self.getnotes()
         id = self.source
         if notes:
-            id = u"%s\04%s" % (notes, id)
+            id = "%s\04%s" % (notes, id)
         if context:
-            id = u"%s\04%s" % (context, id)
+            id = "%s\04%s" % (context, id)
         return id
 
     def markfuzzy(self, present=True):
         if present:
-            self.target = u""
+            self.target = ""
 
     def settargetlang(self, newlang):
         self._dict['target-lang'] = newlang
@@ -250,7 +250,7 @@ class CatkeysFile(base.TranslationStore):
 
     def __init__(self, inputfile=None, **kwargs):
         """Construct a catkeys store, optionally reading in from inputfile."""
-        super(CatkeysFile, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.filename = ''
         self.header = CatkeysHeader()
         if inputfile is not None:
@@ -283,8 +283,48 @@ class CatkeysFile(base.TranslationStore):
     def serialize(self, out):
         output = csv.StringIO()
         writer = csv.DictWriter(output, FIELDNAMES, dialect="catkeys")
+        # Calculate/update fingerprint
+        self.header.setchecksum(self._compute_fingerprint())
         # No real headers, the first line contains metadata
         writer.writerow(dict(zip(FIELDNAMES, [self.header._header_dict[key] for key in FIELDNAMES_HEADER])))
         for unit in self.units:
             writer.writerow(unit.dict)
         out.write(output.getvalue().encode(self.encoding))
+
+    def _compute_fingerprint(self):
+        """
+        Compute the current hash key in the header for the current state of the store.
+        """
+
+        def hashfun(string, startValue):
+            """
+            This function is on CatKey::HashFun(). In this implementation C integer overflow is emulated.
+            https://github.com/haiku/haiku/blob/b65adbdfbc322bb7d86d74049389c688e9962f15/src/kits/locale/HashMapCatalog.cpp#L93
+            """
+            h = startValue
+            array = string.encode('utf-8')
+
+            for byte in array:
+                if byte > 127:
+                    byte -= 256
+                h = 5 * h + byte
+                h &= 0xFFFFFFFF
+
+            # Add 1
+            h = 5 * h + 1
+            h &= 0xFFFFFFFF
+
+            return h
+
+        fingerprint = 0
+        for unit in self.units:
+            stringhash = hashfun(unit.source, 0)
+            stringhash &= 0xFFFFFFFF
+            stringhash = hashfun(unit.getcontext(), stringhash)
+            stringhash &= 0xFFFFFFFF
+            stringhash = hashfun(unit.getnotes(), stringhash)
+            stringhash &= 0xFFFFFFFF
+            fingerprint += stringhash
+            fingerprint &= 0xFFFFFFFF
+
+        return fingerprint
