@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2008 Zuza Software Foundation
 #
@@ -33,7 +32,7 @@ comments.
 
 import os
 import re
-import six
+import struct
 import warnings
 from io import BytesIO
 
@@ -44,7 +43,8 @@ from translate.misc import quote, wStringIO
 
 normalfilenamechars = b"/#.0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
 normalizetable = b""
-for i in map(six.int2byte, range(256)):
+int2byte = struct.Struct(">B").pack
+for i in map(int2byte, range(256)):
     if i in normalfilenamechars:
         normalizetable += i
     else:
@@ -59,7 +59,7 @@ class unormalizechar(dict):
             self.normalchars[ord(char)] = char
 
     def __getitem__(self, key):
-        return self.normalchars.get(key, u"_")
+        return self.normalchars.get(key, "_")
 
 
 unormalizetable = unormalizechar(normalfilenamechars.decode("ascii"))
@@ -131,7 +131,7 @@ def unescape_text(text):
         .replace("\\r", "\r").replace("\a", "\\\\")
 
 
-helptagre = re.compile('''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
+helptagre = re.compile(r'''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
 
 
 def escape_help_text(text):
@@ -162,7 +162,7 @@ def unescape_help_text(text):
     return text.replace(r"\<", "<").replace(r"\>", ">").replace(r'\"', '"').replace(r"\\", "\\")
 
 
-class ooline(object):
+class ooline:
     """this represents one line, one translation in an .oo file"""
 
     def __init__(self, parts=None):
@@ -228,7 +228,6 @@ class ooline(object):
                 self.localid, self.platform)
 
 
-@six.python_2_unicode_compatible
 class oounit:
     """this represents a number of translations of a resource"""
 
@@ -257,7 +256,7 @@ class oounit:
                 lines = [new_line]
         else:
             lines = self.lines
-        return "\r\n".join([six.text_type(line) for line in lines])
+        return "\r\n".join([str(line) for line in lines])
 
 
 class oofile:
@@ -307,13 +306,6 @@ class oofile:
             thisline = ooline(parts)
             self.addline(thisline)
 
-    def __str__(self, *args, **kwargs):
-        if six.PY2:
-            out = BytesIO()
-            self.serialize(out, **kwargs)
-            return out.getvalue()
-        return super(oofile, self).__str__()
-
     def __bytes__(self):
         out = BytesIO()
         self.serialize(out)
@@ -413,7 +405,7 @@ class oomultifile:
     def openinputfile(self, subfile):
         """returns a pseudo-file object for the given subfile"""
         subfilesrc = self.getsubfilesrc(subfile)
-        inputfile = wStringIO.StringIO(subfilesrc)
+        inputfile = BytesIO(subfilesrc.encode())
         inputfile.filename = subfile
         return inputfile
 
