@@ -1,3 +1,4 @@
+from copy import deepcopy
 
 import pytest
 from lxml import etree
@@ -521,6 +522,21 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         store.units[1].target = "&appName; Core"
         assert bytes(store) == content
 
+    def test_invalid_entity(self):
+        content = '''<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE resources [
+<!ENTITY appName "Linphone">
+]>
+<resources>
+    <string name="app_name">&appName;</string>
+    <string name="app_core">&appName; Core</string>
+</resources>'''
+        store = self.StoreClass()
+        store.parse(content.encode())
+        store.units[0].target = "&appName;"
+        store.units[1].target = "&otherName; Core"
+        assert bytes(store).decode() == content.replace('&appName; Core', '&amp;otherName; Core')
+
     def test_indent(self):
         content = '''<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE resources [
@@ -552,7 +568,7 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
         ])
         assert bytes(store) == content
 
-    def test_entity_add(self):
+    def test_entity_add(self, edit=True):
         content = '''<?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE resources [
 <!ENTITY appName "Zkouška">
@@ -560,14 +576,25 @@ class TestAndroidResourceFile(test_monolingual.TestMonolingualStore):
 <resources>
     <string name="app_name">&appName;</string>
     <string name="app_core">&appName; Core</string>
-</resources>'''.encode('utf-8')
+</resources>'''
         store = self.StoreClass()
-        store.parse(content)
+        store.parse(content.encode())
         second = self.StoreClass()
-        second.addunit(store.units[0], True)
-        second.addunit(store.units[1], True)
-        store = self.StoreClass()
-        assert bytes(second) == content
+        newunit = deepcopy(store.units[0])
+        second.addunit(newunit, True)
+        if edit:
+            newunit.target = "&appName;"
+        newunit = deepcopy(store.units[1])
+        second.addunit(newunit, True)
+        if edit:
+            newunit.target = "&appName; Core"
+        # The original store should be unchanged
+        assert bytes(store).decode() == content
+        # The new store should have same content
+        assert bytes(second).decode() == content
+
+    def test_entity_add_noedit(self):
+        self.test_entity_add(edit=False)
 
     def test_markup_remove(self):
         template = '''<?xml version="1.0" encoding="utf-8"?>
