@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
 
-import six
+from io import BytesIO
+
 from pytest import raises
 
-from translate.misc import wStringIO
 from translate.misc.multistring import multistring
 from translate.storage import pypo, test_po
 
@@ -59,7 +57,7 @@ class TestHelpers():
 
         See :issue:`3140`
         """
-        assert pypo.quoteforpo('''You can get a copy of your Recovery Key by going to &syncBrand.shortName.label; Options on your other device, and selecting  "My Recovery Key" under "Manage Account".''') == [u'""', u'"You can get a copy of your Recovery Key by going to "', u'"&syncBrand.shortName.label; Options on your other device, and selecting  \\""', u'"My Recovery Key\\" under \\"Manage Account\\"."']
+        assert pypo.quoteforpo('''You can get a copy of an recovery key by going to "My Recovery Key" under "Manage Account".''') == ['""', '"You can get a copy of an recovery key by going to \\"My Recovery Key\\" under "', '"\\"Manage Account\\"."']
 
 
 class TestPYPOUnit(test_po.TestPOUnit):
@@ -83,11 +81,11 @@ class TestPYPOUnit(test_po.TestPOUnit):
         assert unit.target.strings == ["Koei", "Koeie"]
         assert unit.target == "Koei"
 
-        unit.target = [u"Sk\u00ear", u"Sk\u00eare"]
+        unit.target = ["Sk\u00ear", "Sk\u00eare"]
         assert isinstance(unit.target, multistring)
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target == u"Sk\u00ear"
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target == "Sk\u00ear"
 
     def test_plural_reduction(self):
         """checks that reducing the number of plurals supplied works"""
@@ -131,8 +129,10 @@ class TestPYPOUnit(test_po.TestPOUnit):
         assert unit.getnotes() == "# Double commented comment"
 
     def test_wrap_firstlines(self):
-        '''tests that we wrap the first line correctly a first line if longer then 71 chars
-        as at 71 chars we should align the text on the left and preceed with with a msgid ""'''
+        """
+        tests that we wrap the first line correctly a first line if longer then 71 chars
+        as at 71 chars we should align the text on the left and preceed with with a msgid ""
+        """
         # longest before we wrap text
         str_max = "123456789 123456789 123456789 123456789 123456789 123456789 123456789 1"
         unit = self.UnitClass(str_max)
@@ -233,22 +233,18 @@ class TestPYPOFile(test_po.TestPOFile):
 
     def test_output_str_unicode(self):
         """checks that we can str(element) which is in unicode"""
-        posource = u'''#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n'''
-        pofile = self.StoreClass(wStringIO.StringIO(posource.encode("UTF-8")), encoding="UTF-8")
+        posource = '''#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n'''
+        pofile = self.StoreClass(BytesIO(posource.encode("UTF-8")), encoding="UTF-8")
         assert len(pofile.units) == 1
         print(bytes(pofile))
         thepo = pofile.units[0]
-        # On Python 2, str() returns bytestrings while on Python 3, str() returns unicode
-        assert str(thepo) == posource if six.PY3 else posource.encode("UTF-8")
-        assert six.text_type(thepo) == posource
+        assert str(thepo) == posource
         # Now if we set the msgstr to Unicode
         # this is an escaped half character (1/2)
         halfstr = b"\xbd ...".decode("latin-1")
         thepo.target = halfstr
-        assert halfstr in six.text_type(thepo)
+        assert halfstr in str(thepo)
         thepo.target = halfstr.encode("UTF-8")
-        if six.PY2:
-            assert halfstr.encode("UTF-8") in str(thepo)
 
     def test_posections(self):
         """checks the content of all the expected sections of a PO message"""
@@ -262,6 +258,26 @@ class TestPYPOFile(test_po.TestPOFile):
         assert pofile.units[0].sourcecomments == ["#: source comment\n"]
         assert pofile.units[0].typecomments == ["#, fuzzy\n"]
 
+    def test_typecomments(self):
+        """test typecomments handling"""
+        posource = """#: 00-8C-41-10-00-00-31-10-12-05-42-44-00-2E
+#, max-length:10
+msgctxt "0"
+msgid "Aurora"
+msgstr ""
+"""
+        pofile = self.poparse(posource)
+        print(pofile)
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+        unit = pofile.units[0]
+        assert unit.typecomments == ["#, max-length:10\n"]
+        assert unit.hastypecomment("max-length:10") is True
+        unit.target = "Aurora"
+        unit.markfuzzy()
+        assert unit.typecomments == ["#, fuzzy, max-length:10\n"]
+        assert unit.hastypecomment("max-length:10") is True
+
     def test_unassociated_comments(self):
         """tests behaviour of unassociated comments."""
         oldsource = '# old lonesome comment\n\nmsgid "one"\nmsgstr "een"\n'
@@ -336,16 +352,16 @@ msgstr[1] "toetse"
         pofile = self.poparse(posource)
 
         assert pofile.units[1].prev_msgctxt == []
-        assert pofile.units[1].prev_source == multistring([u"trea"])
+        assert pofile.units[1].prev_source == multistring(["trea"])
 
         assert pofile.units[2].prev_msgctxt == []
-        assert pofile.units[2].prev_source == multistring([u"trea", u"treas"])
+        assert pofile.units[2].prev_source == multistring(["trea", "treas"])
 
-        assert pofile.units[3].prev_msgctxt == [u'"context 1"']
-        assert pofile.units[3].prev_source == multistring([u"tast"])
+        assert pofile.units[3].prev_msgctxt == ['"context 1"']
+        assert pofile.units[3].prev_source == multistring(["tast"])
 
-        assert pofile.units[4].prev_msgctxt == [u'"context 2"']
-        assert pofile.units[4].prev_source == multistring([u"tast", u"tasts"])
+        assert pofile.units[4].prev_msgctxt == ['"context 2"']
+        assert pofile.units[4].prev_source == multistring(["tast", "tasts"])
 
         assert bytes(pofile).decode('utf-8') == posource
 
@@ -461,3 +477,56 @@ msgstr "FcoeClient"
         assert pofile.units[0].source == ''
         assert pofile.units[1].source == 'FcoeClient'
         assert bytes(pofile) == posource[3:]
+
+    def test_long_msgidcomments(self):
+        posource = """#: networkstatus/connectionmanager.cpp:148
+msgid ""
+"_: Message shown when a network connection failed.  The placeholder contains "
+"the concrete description of the operation eg 'while performing this "
+"operation\\n"
+""
+"A network connection failed %1.  Do you want to place the application in "
+"offline mode?"
+msgstr ""
+"Připojení k síti se nezdařilo: %1. Chcete aplikaci přepnout do režimu "
+"offline?"
+"""
+        pofile = self.poparse(posource.encode('utf-8'))
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+        posource_extra = """#: networkstatus/connectionmanager.cpp:148
+msgid ""
+""
+"_: Message shown when a network connection failed.  The placeholder contains "
+"the concrete description of the operation eg 'while performing this "
+"operation\\n"
+""
+"A network connection failed %1.  Do you want to place the application in "
+"offline mode?"
+msgstr ""
+"Připojení k síti se nezdařilo: %1. Chcete aplikaci přepnout do režimu "
+"offline?"
+"""
+        pofile = self.poparse(posource_extra.encode('utf-8'))
+        assert len(pofile.units) == 1
+        assert bytes(pofile).decode('utf-8') == posource
+
+    def test_incomplete(self):
+        """checks that empty file raises error"""
+        posource = b'''msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+EXTRA
+'''
+        with raises(ValueError):
+            self.poparse(posource)
+
+    def test_invalid(self):
+        """checks that empty file raises error"""
+        posource = b'''README
+
+This is just a random text file.
+'''
+        with raises(ValueError):
+            self.poparse(posource)
