@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function
 
 from translate.storage import test_base, wordfast as wf
 
 
-class TestWFTime(object):
+class TestWFTime:
 
     def test_timestring(self):
         """Setting and getting times set using a timestring"""
@@ -25,11 +23,12 @@ class TestWFUnit(test_base.TestTranslationUnit):
     UnitClass = wf.WordfastUnit
 
     def test_difficult_escapes(self):
-        r"""Wordfast files need to perform magic with escapes.
+        r"""
+        Wordfast files need to perform magic with escapes.
 
-           Wordfast does not accept line breaks in its TM (even though they would be
-           valid in CSV) thus we turn \\n into \n and reimplement the base class test but
-           eliminate a few of the actual tests.
+        Wordfast does not accept line breaks in its TM (even though they would
+        be valid in CSV) thus we turn \\n into \n and reimplement the base
+        class test but eliminate a few of the actual tests.
         """
         unit = self.unit
         specials = ['\\"', '\\ ',
@@ -54,7 +53,7 @@ class TestWFUnit(test_base.TestTranslationUnit):
         for escaped, real in wf.WF_ESCAPE_MAP[:16]:  # Only common and Windows, not testing Mac
             compare(real, escaped)
         # Real world cases
-        unit = self.UnitClass(u"Open &File. ’n Probleem.")
+        unit = self.UnitClass("Open &File. ’n Probleem.")
         assert unit.dict['source'] == "Open &'26;File. &'92;n Probleem."
 
     def test_newlines(self):
