@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008-2011 Zuza Software Foundation
 #
@@ -32,39 +31,18 @@ both.
 `2 <http://doc.qt.io/qt-5/qstring.html#arg-2>`_
 """
 
-import six
 from lxml import etree
 
 from translate.lang import data
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.misc.xml_helpers import reindent
-from translate.storage import base, lisa
+from translate.storage import lisa
 from translate.storage.placeables import general
 from translate.storage.workflow import StateEnum as state
 
 
 # TODO: handle translation types
 
-NPLURALS = {
-    'jp': 1,
-    'en': 2,
-    'fr': 2,
-    'lv': 3,
-    'ga': 3,
-    'cs': 3,
-    'sk': 3,
-    'mk': 3,
-    'lt': 3,
-    'ru': 3,
-    'pl': 3,
-    'ro': 3,
-    'sl': 4,
-    'mt': 4,
-    'cy': 5,
-    'ar': 6,
-}
-
 
 class tsunit(lisa.LISAunit):
     """A single term in the TS file."""
@@ -82,7 +60,6 @@ class tsunit(lisa.LISAunit):
 
     statemap = {
         "obsolete": S_OBSOLETE,
-        "vanished": S_OBSOLETE,
         "unfinished": S_FUZZY,
         "": S_TRANSLATED,
         None: S_TRANSLATED,
@@ -96,7 +73,7 @@ class tsunit(lisa.LISAunit):
         S_TRANSLATED: (state.UNREVIEWED, state.MAX),
     }
 
-    statemap_r = dict((i[1], i[0]) for i in six.iteritems(statemap))
+    statemap_r = dict((i[1], i[0]) for i in statemap.items())
     _context = None
 
     def createlanguageNode(self, lang, text, purpose):
@@ -116,7 +93,10 @@ class tsunit(lisa.LISAunit):
         return self.xmlelement.find(self.namespaced(self.languageNode))
 
     def _gettargetnode(self):
-        return self.xmlelement.find(self.namespaced("translation"))
+        result = self.xmlelement.find(self.namespaced("translation"))
+        if result is not None:
+            return result
+        return etree.SubElement(self.xmlelement, self.namespaced("translation"))
 
     def getlanguageNodes(self):
         """We override this to get source and target nodes."""
@@ -131,22 +111,14 @@ class tsunit(lisa.LISAunit):
             return multistring([text])
         return text
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     @property
     def target(self):
         targetnode = self._gettargetnode()
-        if targetnode is None:
-            etree.SubElement(self.xmlelement, self.namespaced("translation"))
-            return None
         if self.hasplural():
             numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
-            return multistring([data.forceunicode(node.text) or u"" for node in numerus_nodes])
+            return multistring([data.forceunicode(node.text) or "" for node in numerus_nodes])
         else:
-            return data.forceunicode(targetnode.text) or u""
+            return data.forceunicode(targetnode.text) or ""
 
     @target.setter
     def target(self, target):
@@ -175,14 +147,9 @@ class tsunit(lisa.LISAunit):
             self.xmlelement.set("numerus", "yes")
             for string in strings:
                 numerus = etree.SubElement(targetnode, self.namespaced("numerusform"))
-                numerus.text = data.forceunicode(string) or u""
+                numerus.text = data.forceunicode(string) or ""
         else:
-            targetnode.text = data.forceunicode(target) or u""
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
+            targetnode.text = data.forceunicode(target) or ""
 
     def hasplural(self):
         return self.xmlelement.get("numerus") == "yes"
@@ -230,10 +197,7 @@ class tsunit(lisa.LISAunit):
 
     def _gettype(self):
         """Returns the type of this translation."""
-        targetnode = self._gettargetnode()
-        if targetnode is not None:
-            return targetnode.get("type")
-        return None
+        return self._gettargetnode().get("type")
 
     def _settype(self, value=None):
         """Set the type of this translation."""
@@ -342,7 +306,7 @@ class tsunit(lisa.LISAunit):
         return locations
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
-        super(tsunit, self).merge(otherunit, overwrite, comments)
+        super().merge(otherunit, overwrite, comments)
         # TODO: check if this is necessary:
         if otherunit.isfuzzy():
             self.markfuzzy()
@@ -361,6 +325,8 @@ class tsunit(lisa.LISAunit):
                 return self.S_FUZZY
             else:
                 return self.S_UNTRANSLATED
+        elif type == "vanished":
+            return self.S_OBSOLETE
         return self.statemap[type]
 
     def set_state_n(self, value):
@@ -392,7 +358,7 @@ class tsfile(lisa.LISAfile):
 
     def __init__(self, *args, **kwargs):
         self._contextname = None
-        lisa.LISAfile.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def initbody(self):
         """Initialises self.body."""
@@ -444,7 +410,7 @@ class tsfile(lisa.LISAfile):
         name = etree.SubElement(context, self.namespaced("name"))
         name.text = contextname
         if comment:
-            comment_node = context.SubElement(context, "comment")
+            comment_node = etree.SubElement(context, "comment")
             comment_node.text = comment
         return context
 
@@ -466,7 +432,7 @@ class tsfile(lisa.LISAfile):
                 return contextnode
         return None
 
-    def addunit(self, unit, new=True, contextname=None, createifmissing=True):
+    def addunit(self, unit, new=True, contextname=None, comment=None, createifmissing=True):
         """Adds the given unit to the last used body node (current context).
 
         If the contextname is specified, switch to that context (creating it if
@@ -476,13 +442,13 @@ class tsfile(lisa.LISAfile):
             contextname = unit.getcontextname()
 
         if self._contextname != contextname:
-            if not self._switchcontext(contextname, createifmissing):
+            if not self._switchcontext(contextname, comment, createifmissing):
                 return None
-        super(tsfile, self).addunit(unit, new)
+        super().addunit(unit, new)
 #        lisa.setXMLspace(unit.xmlelement, "preserve")
         return unit
 
-    def _switchcontext(self, contextname, createifmissing=False):
+    def _switchcontext(self, contextname, comment, createifmissing=False):
         """Switch the current context to the one named contextname, optionally
         creating it if it doesn't exist.
         """
@@ -491,7 +457,7 @@ class tsfile(lisa.LISAfile):
         if contextnode is None:
             if not createifmissing:
                 return False
-            contextnode = self._createcontext(contextname)
+            contextnode = self._createcontext(contextname, comment)
 
         self.body = contextnode
         if self.body is None:
@@ -499,11 +465,10 @@ class tsfile(lisa.LISAfile):
         return True
 
     def nplural(self):
-        lang = self.header.get("language")
-        if lang in NPLURALS:
-            return NPLURALS[lang]
-        else:
+        lang = data.get_language(self.header.get("language"))
+        if lang is None:
             return 1
+        return lang[1]
 
     def serialize(self, out):
         """Write the XML document to a file."""
