@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
+from io import BytesIO
 
 import pytest
 from pytest import mark
 
-from translate.misc import wStringIO
 from translate.storage import po, xliff
 from translate.tools import pomerge
 
@@ -18,7 +16,8 @@ def test_str2bool():
     assert not pomerge.str2bool("no")
     assert not pomerge.str2bool("false")
     assert not pomerge.str2bool("0")
-    pytest.raises(ValueError, pomerge.str2bool, "2")
+    with pytest.raises(ValueError):
+        pomerge.str2bool("2")
 
 
 class TestPOMerge:
@@ -34,11 +33,10 @@ class TestPOMerge:
     def mergestore(self, templatesource, inputsource, mergeblanks="yes",
                    mergefuzzy="yes",
                    mergecomments="yes"):
-        """merges the sources of the given files and returns a new pofile
-        object"""
-        templatefile = wStringIO.StringIO(templatesource)
-        inputfile = wStringIO.StringIO(inputsource)
-        outputfile = wStringIO.StringIO()
+        """merges the sources of the given files and returns a new pofile object"""
+        templatefile = BytesIO(templatesource.encode())
+        inputfile = BytesIO(inputsource.encode())
+        outputfile = BytesIO()
         assert pomerge.mergestore(inputfile, outputfile, templatefile,
                                   mergeblanks=mergeblanks,
                                   mergefuzzy=mergefuzzy,
@@ -50,11 +48,10 @@ class TestPOMerge:
     def mergexliff(self, templatesource, inputsource, mergeblanks="yes",
                    mergefuzzy="yes",
                    mergecomments="yes"):
-        """merges the sources of the given files and returns a new xlifffile
-        object"""
-        templatefile = wStringIO.StringIO(templatesource)
-        inputfile = wStringIO.StringIO(inputsource)
-        outputfile = wStringIO.StringIO()
+        """merges the sources of the given files and returns a new xlifffile object"""
+        templatefile = BytesIO(templatesource.encode())
+        inputfile = BytesIO(inputsource.encode())
+        outputfile = BytesIO()
         assert pomerge.mergestore(inputfile, outputfile, templatefile,
                                   mergeblanks=mergeblanks,
                                   mergefuzzy=mergefuzzy,
@@ -73,20 +70,19 @@ class TestPOMerge:
             return len(pofile.units)
 
     def singleunit(self, pofile):
-        """checks that the pofile contains a single non-header unit, and
-        returns it"""
+        """checks that the pofile contains a single non-header unit, and returns it"""
         assert self.countunits(pofile) == 1
         return pofile.units[-1]
 
     def test_mergesore_bad_data(self):
         """Test that we catch bad options sent to mergestore"""
-        templatefile = wStringIO.StringIO("")
-        inputfile = wStringIO.StringIO("")
-        outputfile = wStringIO.StringIO()
-        pytest.raises(ValueError, pomerge.mergestore, inputfile, outputfile,
-                      templatefile, mergeblanks="yay")
-        pytest.raises(ValueError, pomerge.mergestore, inputfile, outputfile,
-                      templatefile, mergecomments="yay")
+        templatefile = BytesIO(b"")
+        inputfile = BytesIO(b"")
+        outputfile = BytesIO()
+        with pytest.raises(ValueError):
+            pomerge.mergestore(inputfile, outputfile, templatefile, mergeblanks="yay")
+        with pytest.raises(ValueError):
+            pomerge.mergestore(inputfile, outputfile, templatefile, mergecomments="yay")
 
     def test_simplemerge(self):
         """checks that a simple po entry merges OK"""
@@ -146,8 +142,10 @@ msgstr "Dimpled Ring"'''
         assert not pounit.isfuzzy()
 
     def test_merging_locations(self):
-        """check that locations on separate lines are output in Gettext form
-        of all on one line"""
+        """
+        check that locations on separate lines are output in Gettext form
+        of all on one line
+        """
         templatepo = '''#: location.c:1\n#: location.c:2\nmsgid "Simple String"\nmsgstr ""\n'''
         inputpo = '''#: location.c:1\n#: location.c:2\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
         expectedpo = '''#: location.c:1%slocation.c:2\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n''' % po.lsep
@@ -192,13 +190,15 @@ msgstr "Dimpled Ring"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_reflowed_source_comments(self):
-        """ensure that we don't duplicate source comments (locations) if they
-        have been reflowed"""
+        """
+        ensure that we don't duplicate source comments (locations) if they
+        have been reflowed
+        """
         templatepo = '''#: newMenu.label\n#: newMenu.accesskey\nmsgid "&New"\nmsgstr ""\n'''
         newpo = '''#: newMenu.label newMenu.accesskey\nmsgid "&New"\nmsgstr "&Nuwe"\n'''
         expectedpo = '''#: newMenu.label%snewMenu.accesskey\nmsgid "&New"\nmsgstr "&Nuwe"\n''' % po.lsep
         pofile = self.mergestore(templatepo, newpo)
-        pounit = self.singleunit(pofile)
+        self.singleunit(pofile)
         print(pofile)
         assert bytes(pofile).decode('utf-8') == expectedpo
 
@@ -214,13 +214,15 @@ msgstr "blabla"
         newpo = templatepo
         expectedpo = templatepo
         pofile = self.mergestore(templatepo, newpo)
-        pounit = self.singleunit(pofile)
+        self.singleunit(pofile)
         print(pofile)
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merge_dont_delete_unassociated_comments(self):
-        """ensure that we do not delete comments in the PO file that are not
-        assocaited with a message block"""
+        """
+        ensure that we do not delete comments in the PO file that are not
+        assocaited with a message block
+        """
         templatepo = '''# Lonely comment\n\n# Translation comment\nmsgid "Bob"\nmsgstr "Toolmaker"\n'''
         mergepo = '''# Translation comment\nmsgid "Bob"\nmsgstr "Builder"\n'''
         expectedpo = '''# Lonely comment\n# Translation comment\nmsgid "Bob"\nmsgstr "Builder"\n'''
@@ -247,8 +249,10 @@ msgstr "blabla"
         assert bytes(pofile).decode('utf-8') == expectedpo or bytes(pofile) == expectedpo2
 
     def test_preserve_format_minor_start_and_end_of_sentence_changes(self):
-        """Test that we are not too fussy about large diffs for simple
-        changes at the start or end of a sentence"""
+        """
+        Test that we are not too fussy about large diffs for simple
+        changes at the start or end of a sentence
+        """
         templatepo = '''msgid "Target type:"\nmsgstr "Doelsoort"\n\n'''
         mergepo = '''msgid "Target type:"\nmsgstr "Doelsoort:"\n'''
         expectedpo = mergepo
@@ -271,8 +275,10 @@ msgstr "blabla"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_preserve_format_last_entry_in_a_file(self):
-        """The last entry in a PO file is usualy not followed by an empty
-        line.  Test that we preserve this"""
+        """
+        The last entry in a PO file is usualy not followed by an empty
+        line.  Test that we preserve this
+        """
         templatepo = '''msgid "First"\nmsgstr ""\n\nmsgid "Second"\nmsgstr ""\n'''
         mergepo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
         expectedpo = '''msgid "First"\nmsgstr "Eerste"\n\nmsgid "Second"\nmsgstr "Tweede"\n'''
@@ -289,8 +295,7 @@ msgstr "blabla"
 
     @mark.xfail(reason="Not Implemented")
     def test_escape_tabs(self):
-        """Ensure that input tabs are escaped in the output, like
-        gettext does."""
+        """Ensure that input tabs are escaped in the output, like gettext does."""
 
         # The strings below contains the tab character, not spaces.
         templatepo = '''msgid "First	Second"\nmsgstr ""\n\n'''
@@ -303,8 +308,10 @@ msgstr "Eerste\tTweede"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_preserve_comments_layout(self):
-        """Ensure that when we merge with new '# (poconflict)' or other
-        comments that we don't mess formating"""
+        """
+        Ensure that when we merge with new '# (poconflict)' or other
+        comments that we don't mess formating
+        """
         templatepo = '''#: filename\nmsgid "Desktop Background.bmp"\nmsgstr "Desktop Background.bmp"\n\n'''
         mergepo = '''# (pofilter) unchanged: please translate\n#: filename\nmsgid "Desktop Background.bmp"\nmsgstr "Desktop Background.bmp"\n'''
         expectedpo = mergepo
@@ -313,8 +320,7 @@ msgstr "Eerste\tTweede"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merge_dos2unix(self):
-        """Test that merging a comment line with dos newlines doesn't add a
-        new line"""
+        """Test that merging a comment line with dos newlines doesn't add a new line"""
         templatepo = '''# User comment\n# (pofilter) Translate Toolkit comment\n#. Automatic comment\n#: location_comment.c:110\nmsgid "File"\nmsgstr "File"\n\n'''
         mergepo = '''# User comment\r\n# (pofilter) Translate Toolkit comment\r\n#. Automatic comment\r\n#: location_comment.c:110\r\nmsgid "File"\r\nmsgstr "Ifayile"\r\n\r\n'''
         expectedpo = '''# User comment\n# (pofilter) Translate Toolkit comment\n#. Automatic comment\n#: location_comment.c:110\nmsgid "File"\nmsgstr "Ifayile"\n'''
@@ -373,8 +379,7 @@ msgstr "Eerste\tTweede"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merging_dont_merge_kde_comments_found_in_translation(self):
-        """If we find a KDE comment in the translation (target) then do not
-        merge it."""
+        """If we find a KDE comment in the translation (target) then do not merge it."""
 
         templatepo = '''msgid "_: KDE comment\\n"\n"File"\nmsgstr "File"\n\n'''
         mergepo = '''msgid "_: KDE comment\\n"\n"File"\nmsgstr "_: KDE comment\\n"\n"Ifayile"\n\n'''
@@ -397,8 +402,7 @@ msgstr "Eerste\tTweede"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merging_untranslated_with_kde_disambiguation(self):
-        """test merging untranslated messages that are the same except for
-        KDE disambiguation"""
+        """test merging untranslated messages that are the same except for KDE disambiguation"""
         templatepo = r'''#: sendMsgTitle
 #: sendMsgTitle.accesskey
 msgid "_: sendMsgTitle sendMsgTitle.accesskey\n"
@@ -429,8 +433,7 @@ msgstr "Stuur"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merging_header_entries(self):
-        """Check that we do the right thing if we have header entries in the
-        input PO."""
+        """Check that we do the right thing if we have header entries in the input PO."""
 
         templatepo = r'''#, fuzzy
 msgid ""
@@ -492,8 +495,10 @@ msgstr "Dimpled Ring"
         assert bytes(pofile).decode('utf-8') == expectedpo
 
     def test_merging_different_locations(self):
-        """Test when merging units that are unchanged except for changed
-        locations that we don't go fuzzy (bug 1583)"""
+        """
+        Test when merging units that are unchanged except for changed
+        locations that we don't go fuzzy (bug 1583)
+        """
 
         templatepo = r'''#, fuzzy
 msgid ""
