@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 
 import warnings
+from io import BytesIO
 
 from pytest import mark
 
 from translate.convert import test_convert
-from translate.misc import wStringIO
 from translate.storage import po, xliff
 from translate.tools import pretranslate
 
@@ -28,12 +27,12 @@ class TestPretranslate:
 
     def pretranslatepo(self, input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
-        input_file = wStringIO.StringIO(input_source)
+        input_file = BytesIO(input_source.encode())
         if template_source:
-            template_file = wStringIO.StringIO(template_source)
+            template_file = BytesIO(template_source.encode())
         else:
             template_file = None
-        output_file = wStringIO.StringIO()
+        output_file = BytesIO()
 
         pretranslate.pretranslate_file(input_file, output_file, template_file)
         output_file.seek(0)
@@ -41,20 +40,22 @@ class TestPretranslate:
 
     def pretranslatexliff(self, input_source, template_source=None):
         """helper that converts strings to po source without requiring files"""
-        input_file = wStringIO.StringIO(input_source)
+        input_file = BytesIO(input_source)
         if template_source:
-            template_file = wStringIO.StringIO(template_source)
+            template_file = BytesIO(template_source)
         else:
             template_file = None
-        output_file = wStringIO.StringIO()
+        output_file = BytesIO()
 
         pretranslate.pretranslate_file(input_file, output_file, template_file)
         output_file.seek(0)
         return xliff.xlifffile(output_file.read())
 
     def singleunit(self, pofile):
-        """checks that the pofile contains a single non-header unit, and
-        returns it"""
+        """
+        checks that the pofile contains a single non-header unit, and
+        returns it
+        """
         if len(pofile.units) == 2 and pofile.units[0].isheader():
             print(pofile.units[1])
             return pofile.units[1]
@@ -63,31 +64,30 @@ class TestPretranslate:
             return pofile.units[0]
 
     def test_pretranslatepo_blank(self):
-        """checks that the pretranslatepo function is working for a simple file
-        initialisation"""
+        """
+        checks that the pretranslatepo function is working for a simple file
+        initialisation
+        """
         input_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
         newpo = self.pretranslatepo(input_source)
         assert str(self.singleunit(newpo)) == input_source
 
     def test_merging_simple(self):
-        """checks that the pretranslatepo function is working for a simple
-        merge"""
+        """checks that the pretranslatepo function is working for a simple merge"""
         input_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
         template_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.pretranslatepo(input_source, template_source)
         assert str(self.singleunit(newpo)) == template_source
 
     def test_merging_messages_marked_fuzzy(self):
-        """test that when we merge PO files with a fuzzy message that it
-        remains fuzzy"""
+        """test that when we merge PO files with a fuzzy message that it remains fuzzy"""
         input_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
         template_source = '''#: simple.label%ssimple.accesskey\n#, fuzzy\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         newpo = self.pretranslatepo(input_source, template_source)
         assert str(self.singleunit(newpo)) == template_source
 
     def test_merging_plurals_with_fuzzy_matching(self):
-        """test that when we merge PO files with a fuzzy message that it
-        remains fuzzy"""
+        """test that when we merge PO files with a fuzzy message that it remains fuzzy"""
         input_source = r'''#: file.cpp:2
 msgid "%d manual"
 msgid_plural "%d manuals"
@@ -114,8 +114,10 @@ msgstr[1] "%d handleidings."
 
     @mark.xfail(reason="Not Implemented")
     def test_merging_msgid_change(self):
-        """tests that if the msgid changes but the location stays the same that
-        we merge"""
+        """
+        tests that if the msgid changes but the location stays the same that
+        we merge
+        """
         input_source = '''#: simple.label\n#: simple.accesskey\nmsgid "Its &hard coding a newline.\\n"\nmsgstr ""\n'''
         template_source = '''#: simple.label\n#: simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
         poexpected = '''#: simple.label\n#: simple.accesskey\n#, fuzzy\nmsgid "Its &hard coding a newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n'''
@@ -124,8 +126,10 @@ msgstr[1] "%d handleidings."
         assert bytes(newpo).decode('utf-8') == poexpected
 
     def test_merging_location_change(self):
-        """tests that if the location changes but the msgid stays the same that
-        we merge"""
+        """
+        tests that if the location changes but the msgid stays the same that
+        we merge
+        """
         input_source = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr ""\n''' % po.lsep
         template_source = '''#: simple.label%ssimple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
         poexpected = '''#: new_simple.label%snew_simple.accesskey\nmsgid "A &hard coded newline.\\n"\nmsgstr "&Hart gekoeerde nuwe lyne\\n"\n''' % po.lsep
@@ -134,8 +138,10 @@ msgstr[1] "%d handleidings."
         assert bytes(newpo).decode('utf-8') == poexpected
 
     def test_merging_location_and_whitespace_change(self):
-        """test that even if the location changes that if the msgid only has
-        whitespace changes we can still merge"""
+        """
+        test that even if the location changes that if the msgid only has
+        whitespace changes we can still merge
+        """
         input_source = '''#: singlespace.label%ssinglespace.accesskey\nmsgid "&We have spaces"\nmsgstr ""\n''' % po.lsep
         template_source = '''#: doublespace.label%sdoublespace.accesskey\nmsgid "&We  have  spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
         poexpected = '''#: singlespace.label%ssinglespace.accesskey\n#, fuzzy\nmsgid "&We have spaces"\nmsgstr "&One  het  spasies"\n''' % po.lsep
@@ -145,8 +151,10 @@ msgstr[1] "%d handleidings."
 
     @mark.xfail(reason="Not Implemented")
     def test_merging_accelerator_changes(self):
-        """test that a change in the accelerator localtion still allows
-        merging"""
+        """
+        test that a change in the accelerator localtion still allows
+        merging
+        """
         input_source = '''#: someline.c\nmsgid "A&bout"\nmsgstr ""\n'''
         template_source = '''#: someline.c\nmsgid "&About"\nmsgstr "&Info"\n'''
         poexpected = '''#: someline.c\nmsgid "A&bout"\nmsgstr "&Info"\n'''
@@ -156,8 +164,10 @@ msgstr[1] "%d handleidings."
 
     @mark.xfail(reason="Not Implemented")
     def test_lines_cut_differently(self):
-        """Checks that the correct formatting is preserved when pot an po lines
-        differ."""
+        """
+        Checks that the correct formatting is preserved when pot an po lines
+        differ.
+        """
         input_source = '''#: simple.label\nmsgid "Line split "\n"differently"\nmsgstr ""\n'''
         template_source = '''#: simple.label\nmsgid "Line"\n" split differently"\nmsgstr "Lyne verskillend gesny"\n'''
         newpo = self.pretranslatepo(input_source, template_source)
@@ -182,8 +192,10 @@ msgstr[1] "%d handleidings."
         assert str(newpounit) == poexpected
 
     def test_merging_comments_with_blank_comment_lines(self):
-        """test that when we merge a comment that has a blank line we keep the
-        blank line"""
+        """
+        test that when we merge a comment that has a blank line we keep the
+        blank line
+        """
         input_source = '''#: someline.c\nmsgid "About"\nmsgstr ""\n'''
         template_source = '''# comment1\n#\n# comment2\n#: someline.c\nmsgid "About"\nmsgstr "Omtrent"\n'''
         poexpected = template_source
@@ -241,8 +253,10 @@ msgstr "36em"
         assert str(newpounit) == template_source
 
     def test_merging_resurect_obsolete_messages(self):
-        """check that we can reuse old obsolete messages if the message comes
-        back"""
+        """
+        check that we can reuse old obsolete messages if the message comes
+        back
+        """
         input_source = '''#: resurect.c\nmsgid "&About"\nmsgstr ""\n'''
         template_source = '''#~ msgid "&About"\n#~ msgstr "&Omtrent"\n'''
         expected = '''#: resurect.c\nmsgid "&About"\nmsgstr "&Omtrent"\n'''
@@ -292,7 +306,8 @@ msgstr "36em"
 
         template = xliff.xlifffile.parsestring(xlf_template)
         old = xliff.xlifffile.parsestring(xlf_old)
-        new = self.pretranslatexliff(template, old)
+        # Serialize files
+        new = self.pretranslatexliff(bytes(template), bytes(old))
         print(bytes(old))
         print('---')
         print(bytes(new))
@@ -303,11 +318,12 @@ msgstr "36em"
 
 class TestPretranslateCommand(test_convert.TestConvertCommand, TestPretranslate):
     """Tests running actual pretranslate commands on files"""
+
     convertmodule = pretranslate
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--tm")
         options = self.help_check(options, "-s MIN_SIMILARITY, --similarity=MIN_SIMILARITY")
